@@ -24,12 +24,18 @@ from collections.abc import Mapping
 import re
 import logging
 import sys
+import hashlib
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
+from chapps.signals import TooManyAtsException, NotAnEmailAddressException
 
 logger = logging.getLogger(__name__)
 
 
+def hash_password(password: str, encoding: str = "utf-8") -> str:
+    return hashlib.sha256(password.encode(encoding)).hexdigest()
+
+
 class VenvDetector:
     """Detect use of a virtual environment and calculate local paths
 
@@ -206,7 +212,7 @@ class AttrDict:
     def __init__(
         self, data: Dict[str, Any] = None, **kwargs: Optional[Dict[str, Any]]
     ):
-        """Populate an instance with attributes
+        r"""Populate an instance with attributes
 
         :param data: a :obj:`dict` mapping strings (attribute names) onto arbitrary values
 
@@ -367,7 +373,7 @@ class PostfixPolicyRequest(Mapping):
 
     """
 
-    def __init__(self, payload: List[str]):
+    def __init__(self, payload: List[str], *args, **kwargs):
         """Store the payload.
 
         :param List[str] payload: strings which are formatted as 'key=val',
@@ -414,7 +420,8 @@ class PostfixPolicyRequest(Mapping):
             (l for l in self._payload if attr == l.split("=")[0]), None
         )
         if line:
-            key, value = line.split("=")
+            key, *values = line.split("=")
+            value = "=".join(values)
             setattr(self, key, value)
             return value
         else:
@@ -440,7 +447,8 @@ class PostfixPolicyRequest(Mapping):
         """
         if not getattr(self, "_mapping", None):
             self._mapping = {
-                k: v for k, v in [l.split("=") for l in self._payload]
+                k: "=".join(vs)
+                for k, *vs in [l.split("=") for l in self._payload]
             }
             # Since we end up parsing the entire payload
             # optimize it for future random access
@@ -493,3 +501,25 @@ class PostfixPolicyRequest(Mapping):
                 else []
             )
         return self._recipients
+
+    def domain_from(self, email_address: str) -> str:
+        """Given an email address, return the domain part
+
+        Raises meaningful errors if nonconforming conditions are encountered.
+        """
+        parts = email_address.split("@")
+        if len(parts) > 2:
+            logger.info(
+                "Found sender email with more than one at-sign: "
+                f"sender={email_address} instance={self.instance} "
+                f"parts={parts!r}"
+            )
+            raise TooManyAtsException(f"{email_address}=>{parts!r}")
+        elif len(parts) == 1:
+            logger.info(
+                "Found sender string without at-sign: "
+                f"sender={email_address} instance={self.instance} "
+                f"parts={parts!r}"
+            )
+            raise NotAnEmailAddressException
+        return parts[-1]
